All of lore.kernel.org
 help / color / mirror / Atom feed
From: Ashutosh Dixit <ashutosh.dixit@intel.com>
To: intel-xe@lists.freedesktop.org
Cc: Gustavo Sousa <gustavo.sousa@intel.com>,
	Matt Roper <matthew.d.roper@intel.com>
Subject: [PATCH 1/2] drm/xe/mcr: Take vcs1/vecs1 into account for first media slice
Date: Fri, 24 Jul 2026 13:11:28 -0700	[thread overview]
Message-ID: <20260724201129.2814030-2-ashutosh.dixit@intel.com> (raw)
In-Reply-To: <20260724201129.2814030-1-ashutosh.dixit@intel.com>

vcs1 and vecs1 may also be present on the first media slice, so take
vcs1/vecs1 also into account when determining if the first media slice is
absent.

Bspec: 77977

Cc: Gustavo Sousa <gustavo.sousa@intel.com>
Cc: Matt Roper <matthew.d.roper@intel.com>
Signed-off-by: Ashutosh Dixit <ashutosh.dixit@intel.com>
---
 drivers/gpu/drm/xe/xe_gt_mcr.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/drivers/gpu/drm/xe/xe_gt_mcr.c b/drivers/gpu/drm/xe/xe_gt_mcr.c
index 9799ffadf85d2..d069d141b54d6 100644
--- a/drivers/gpu/drm/xe/xe_gt_mcr.c
+++ b/drivers/gpu/drm/xe/xe_gt_mcr.c
@@ -454,9 +454,10 @@ static void init_steering_oaddrm(struct xe_gt *gt)
 {
 	/*
 	 * First instance is only terminated if the entire first media slice
 	 * is absent (i.e., no VCS0 or VECS0).
 	 */
-	if (gt->info.engine_mask & (XE_HW_ENGINE_VCS0 | XE_HW_ENGINE_VECS0))
+	if (gt->info.engine_mask & (XE_HW_ENGINE_VCS0 | XE_HW_ENGINE_VCS1 |
+				    XE_HW_ENGINE_VECS0 | XE_HW_ENGINE_VECS0))
 		gt->steering[OADDRM].group_target = 0;
 	else
 		gt->steering[OADDRM].group_target = 1;
@@ -454,9 +454,10 @@ static void init_steering_oaddrm(struct xe_gt *gt)
 	/*
 	 * First instance is only terminated if the entire first media slice
-	 * is absent (i.e., no VCS0 or VECS0).
+	 * is absent (i.e., no VCS0, VCS1, VECS0 or VECS1).
 	 */
-- 
2.54.0


  reply	other threads:[~2026-07-24 20:11 UTC|newest]

Thread overview: 8+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2026-07-24 20:11 [PATCH 0/2] drm/xe: Changes for Xe3p_HPM media Ashutosh Dixit
2026-07-24 20:11 ` Ashutosh Dixit [this message]
2026-07-24 21:15   ` [PATCH 1/2] drm/xe/mcr: Take vcs1/vecs1 into account for first media slice Dixit, Ashutosh
2026-07-24 21:18   ` Matt Roper
2026-07-24 20:11 ` [PATCH 2/2] drm/xe/oa: Extend OAM unit hwe assignment for new dGfx Ashutosh Dixit
2026-07-24 20:17 ` ✗ CI.checkpatch: warning for drm/xe: Changes for Xe3p_HPM media Patchwork
2026-07-24 20:18 ` ✓ CI.KUnit: success " Patchwork
2026-07-24 21:01 ` ✓ Xe.CI.BAT: " Patchwork

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20260724201129.2814030-2-ashutosh.dixit@intel.com \
    --to=ashutosh.dixit@intel.com \
    --cc=gustavo.sousa@intel.com \
    --cc=intel-xe@lists.freedesktop.org \
    --cc=matthew.d.roper@intel.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.